@@ -1,13 +1,15 @@
 package Perinci::CmdLine::Any;
 
-our $DATE = '2021-06-23'; # DATE
-our $VERSION = '0.152'; # VERSION
-
+use strict;
 # IFUNBUILT
-# use strict;
 # use warnings;
 # END IFUNBUILT
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-12-01'; # DATE
+our $DIST = 'Perinci-CmdLine-Any'; # DIST
+our $VERSION = '0.153'; # VERSION
+
 my %Opts = (
     -prefer_lite => 1,
 );
@@ -71,7 +73,7 @@ Perinci::CmdLine::Any - Choose Perinci::CmdLine implementation (::Lite or ::Clas
 
 =head1 VERSION
 
-This document describes version 0.152 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2021-06-23.
+This document describes version 0.153 of Perinci::CmdLine::Any (from Perl distribution Perinci-CmdLine-Any), released on 2021-12-01.
 
 =head1 SYNOPSIS
 
@@ -107,12 +109,6 @@ to override using C<PERINCI_CMDLINE_ANY>):
 
 =for Pod::Coverage ^(new)$
 
-=head1 CONTRIBUTOR
-
-=for stopwords Steven Haryanto
-
-Steven Haryanto <sharyanto@cpan.org>
-
 =head1 ENVIRONMENT
 
 =head2 PERINCI_CMDLINE_ANY => str
@@ -127,14 +123,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Cm
 
 Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Any>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Any>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Perinci::CmdLine::Lite>, L<Perinci::CmdLine::Classic>
@@ -146,11 +134,42 @@ since it works by generating script instead: L<Perinci::CmdLine::Inline>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2014 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2017, 2016, 2015, 2014 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Any>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
